<?php
/**
 * Simple Machines Forum (SMF)
 *
 * @package SMF
 * @author Simple Machines https://www.simplemachines.org
 * @copyright 2022 Simple Machines and individual contributors
 * @license https://www.simplemachines.org/about/smf/license.php BSD
 *
 * @version 2.1.0
 */

/**
 * This pseudo-template defines all the theme options
 */
function template_options()
{
	global $context, $txt, $modSettings;

	$context['theme_options'] = array(
		$txt['theme_opt_display'],
		array(
			'id' => 'show_children',
			'label' => $txt['show_children'],
			'default' => true,
		),
		array(
			'id' => 'topics_per_page',
			'label' => $txt['topics_per_page'],
			'options' => array(
				0 => $txt['per_page_default'],
				5 => 5,
				10 => 10,
				25 => 25,
				50 => 50,
			),
			'default' => true,
			'enabled' => empty($modSettings['disableCustomPerPage']),
		),
		array(
			'id' => 'messages_per_page',
			'label' => $txt['messages_per_page'],
			'options' => array(
				0 => $txt['per_page_default'],
				5 => 5,
				10 => 10,
				25 => 25,
				50 => 50,
			),
			'default' => true,
			'enabled' => empty($modSettings['disableCustomPerPage']),
		),
		array(
			'id' => 'view_newest_first',
			'label' => $txt['recent_posts_at_top'],
			'default' => true,
		),
		array(
			'id' => 'show_no_avatars',
			'label' => $txt['show_no_avatars'],
			'default' => true,
		),
		array(
			'id' => 'show_no_signatures',
			'label' => $txt['show_no_signatures'],
			'default' => true,
		),
		array(
			'id' => 'posts_apply_ignore_list',
			'label' => $txt['posts_apply_ignore_list'],
			'default' => false,
			'enabled' => !empty($modSettings['enable_buddylist'])
		),
		$txt['theme_opt_posting'],
		array(
			'id' => 'return_to_post',
			'label' => $txt['return_to_post'],
			'default' => true,
		),
		array(
			'id' => 'no_new_reply_warning',
			'label' => $txt['no_new_reply_warning'],
			'default' => true,
		),
		array(
			'id' => 'auto_notify',
			'label' => $txt['auto_notify'],
			'default' => true,
		),
		array(
			'id' => 'wysiwyg_default',
			'label' => $txt['wysiwyg_default'],
			'default' => false,
			'enabled' => empty($modSettings['disable_wysiwyg']),
		),
		array(
			'id' => 'drafts_autosave_enabled',
			'label' => $txt['drafts_autosave_enabled'],
			'default' => true,
			'enabled' => !empty($modSettings['drafts_autosave_enabled']) && (!empty($modSettings['drafts_post_enabled']) || !empty($modSettings['drafts_pm_enabled'])),
		),
		array(
			'id' => 'drafts_show_saved_enabled',
			'label' => $txt['drafts_show_saved_enabled'],
			'default' => true,
			'enabled' => !empty($modSettings['drafts_show_saved_enabled']) && (!empty($modSettings['drafts_post_enabled']) || !empty($modSettings['drafts_pm_enabled'])),
		),
		$txt['theme_opt_moderation'],
		array(
			'id' => 'display_quick_mod',
			'label' => $txt['display_quick_mod'],
			'options' => array(
				0 => $txt['display_quick_mod_none'],
				1 => $txt['display_quick_mod_check'],
				2 => $txt['display_quick_mod_image'],
			),
			'default' => true,
		),
		$txt['theme_opt_personal_messages'],
		array(
			'id' => 'popup_messages',
			'label' => $txt['popup_messages'],
			'default' => true,
		),
		array(
			'id' => 'view_newest_pm_first',
			'label' => $txt['recent_pms_at_top'],
			'default' => true,
		),
		array(
			'id' => 'pm_remove_inbox_label',
			'label' => $txt['pm_remove_inbox_label'],
			'default' => true,
		),
		$txt['theme_opt_calendar'],
		array(
			'id' => 'calendar_default_view',
			'label' => $txt['calendar_default_view'],
			'options' => array(
				'viewlist' => $txt['calendar_viewlist'],
				'viewmonth' => $txt['calendar_viewmonth'],
				'viewweek' => $txt['calendar_viewweek']
			),
			'default' => true,
			'enabled' => !empty($modSettings['cal_enabled']),
		),
		array(
			'id' => 'calendar_start_day',
			'label' => $txt['calendar_start_day'],
			'options' => array(
				0 => $txt['days'][0],
				1 => $txt['days'][1],
				6 => $txt['days'][6],
			),
			'default' => true,
			'enabled' => !empty($modSettings['cal_enabled']),
		),
	);
}

/**
 * This pseudo-template defines all the available theme settings (but not their actual values)
 */
function template_settings()
{
	global $context, $txt;

	$context['theme_settings'] = array(
		array(
			'id' => 'header_logo_url',
			'label' => $txt['header_logo_url'],
			'description' => $txt['header_logo_url_desc'],
			'type' => 'text',
		),
		array(
			'id' => 'site_slogan',
			'label' => $txt['site_slogan'],
			'description' => $txt['site_slogan_desc'],
			'type' => 'text',
		),
		array(
			'id' => 'og_image',
			'label' => $txt['og_image'],
			'description' => $txt['og_image_desc'],
			'type' => 'url',
		),
		'',
         array(
        'id' => 'enable_bildir',
        'label' => $txt['enable_bildir'],
        'options' => array(
         0 => $txt['disable_bildir'],
         1 => $txt['guest_bildir'],
         2 => $txt['user_bildir'],
         3 => $txt['all_bildir']
         ),
        'type' => 'number',
        'default' => true,
         ),
        array(
        'id' => 'bildiri',
         'label' => $txt['bildiri'],
         'description' => $txt['bildiri_desc'],
         'type' => 'textarea',
         ),
        array(
         'id' => 'type_bildir',
         'label' => $txt['type_bildir'],
         'options' => array(
         0 => $txt['html_bildir'],
         1 => $txt['bbc_bildir'],
          ),
        'type' => 'number',
        'default' => true,
         ),	
		'',
		array(
			'id' => 'smiley_sets_default',
			'label' => $txt['smileys_default_set_for_theme'],
			'options' => $context['smiley_sets'],
			'type' => 'text',
		),
		'',
		array(
			'id' => 'enable_news',
			'label' => $txt['enable_random_news'],
		),
		array(
			'id' => 'show_newsfader',
			'label' => $txt['news_fader'],
		),
		array(
			'id' => 'newsfader_time',
			'label' => $txt['admin_fader_delay'],
			'type' => 'number',
		),
		'',
		array(
			'id' => 'number_recent_posts',
			'label' => $txt['number_recent_posts'],
			'description' => $txt['zero_to_disable'],
			'type' => 'number',
		),
		array(
			'id' => 'show_stats_index',
			'label' => $txt['show_stats_index'],
		),
		array(
			'id' => 'show_latest_member',
			'label' => $txt['latest_members'],
		),
		array(
			'id' => 'show_group_key',
			'label' => $txt['show_group_key'],
		),
		array(
			'id' => 'display_who_viewing',
			'label' => $txt['who_display_viewing'],
			'options' => array(
				0 => $txt['who_display_viewing_off'],
				1 => $txt['who_display_viewing_numbers'],
				2 => $txt['who_display_viewing_names'],
			),
			'type' => 'list',
		),
	   array(
         'id' => 'top4_onof',
          'label' => $txt['top4_onof'],
		  'description' => $txt['top4_onofalt'],
          ), 
		  '',
	    array(
         'id' => 'mobile_navigation_onoff',
          'label' => $txt['mobile_navigation_onoff'],
          ), 
		  '',	
	    array(
         'id' => 'profil_yagmur_onoff',
          'label' => $txt['profil_yagmur_onoff'],
          ), 
		  '',
		array(
         'id' => 'mobilortareklam_onoff',
          'label' => $txt['mobilortareklam_onoff'],
          ), 
		 array(
         'id' => 'mobilortareklam_link',
         'label' => $txt['mobilortareklam_link'],
         'type' => 'text',
         ),	 
		 array(
         'id' => 'mobilortareklam_resim',
         'label' => $txt['mobilortareklam_resimyolu'],
         'type' => 'text',
         ),	
		 '',	  
		array(
         'id' => 'mobilalt_onoff',
          'label' => $txt['mobilalt_onoff'],
          ), 
		array(
         'id' => 'mobilalt_link',
         'label' => $txt['mobilalt_link'],
         'type' => 'text',
         ),
		 array(
         'id' => 'mobilalt_resim',
         'label' => $txt['mobilalt_resimyolu'],
         'type' => 'text',
         ), 
		 '',	  
		array(
         'id' => 'yanreklam_onoff',
          'label' => $txt['yanreklam_onoff'],
          ), 
	    array(
         'id' => 'yanreklam_resimadres',
         'label' => $txt['yanreklam_resimadresyolu'],
         'type' => 'text',
         ),
		array(
         'id' => 'yanreklam_adres',
         'label' => $txt['yanreklam_adres'],
         'type' => 'text',
         ),	 
	   array(
         'id' => 'yanreklam_resimadres1',
         'label' => $txt['yanreklam_resimadres1yolu'],
         'type' => 'text',
         ),
	    array(
         'id' => 'yanreklam_adres1',
         'label' => $txt['yanreklam_adres1'],
         'type' => 'text',
         ),
		  '', 
		array(
		 'id' => 'custom_title',
		 'label' => $txt['custom_title'],
		 'options' => array(
		 'title' => $txt['title_onoff'],
		 'logo' => $txt['logo_onoff'],
			),
			'type' => 'list',
		),
		array(
         'id' => 'logo_balon',
         'label' => $txt['logo_balon'],
          ),		  
	   array(
         'id' => 'logo_link',
         'label' => $txt['logo_link'],
         'type' => 'text',
         ),	
	   array(
         'id' => 'title_logoanahtarkelime',
         'label' => $txt['title_logoanahtarkelime'],
         'type' => 'text',
         ),		 
       array(
         'id' => 'logo_resimadres',
         'label' => $txt['logo_resimadres'],
         'type' => 'text',
         ),
	   array(
         'id' => 'logo_resimadres1',
         'label' => $txt['logo_resimadres1'],
         'type' => 'text',
         ),
	   array(
         'id' => 'logo_resimadres2',
         'label' => $txt['logo_resimadres2'],
         'type' => 'text',
         ),  
		'', 
		array(
         'id' => 'footer_sosyalonof',
         'label' => $txt['footer_sosyalonof'],
         'default' => false,
          ),
        array(
         'id' => 'foter_link',
         'label' => $txt['foter_link'],
         'type' => 'text',
         ),
		array(
         'id' => 'foter_link1',
         'label' => $txt['foter_link1'],
         'type' => 'text',
         ),
		array(
         'id' => 'foter_link2',
         'label' => $txt['foter_link2'],
         'type' => 'text',
         ),
		array(
         'id' => 'foter_link3',
         'label' => $txt['foter_link3'],
         'type' => 'text',
         ),	 
		 array(
         'id' => 'linkedin_adresin',
         'label' => $txt['linkedin_adresin'],
         'type' => 'text',
         ),
		 array(
         'id' => 'twitter_adresin',
         'label' => $txt['twitter_adresin'],
         'type' => 'text',
         ),	
		 array(
         'id' => 'youtube_adresin',
         'label' => $txt['youtube_adresin'],
         'type' => 'text',
         ),	
		 array(
         'id' => 'github_adresin',
         'label' => $txt['github_adresin'],
         'type' => 'text',
         ),
		 array(
         'id' => 'footer_bilgilendirme',
         'label' => $txt['footer_bilgilendirme'],
		 'type' => 'textarea',
         ),
		 array(
         'id' => 'footer_uyarilar',
         'label' => $txt['footer_uyarilar'],
		 'type' => 'textarea',
         ),			 
		'',
       array(
        'id' => 'slayt_onoff',
        'label' => $txt['slayt_onoff'],
          ),    

         array(
         'id' => 'slayt_adres0',
         'label' => $txt['slayt_adres0'],
         'type' => 'text',
         ),
         array(
         'id' => 'slayt_article_upper0',
         'label' => $txt['slayt_article_upper0'],
         'type' => 'text',
 
         ),
         array(
         'id' => 'slayt_link0',
         'label' => $txt['slayt_link0'],
         'type' => 'text',
 
         ),
         array(
         'id' => 'slayt_article_lower0',
         'label' => $txt['slayt_article_lower0'],
         'type' => 'text',
 
         ),
         '',
         array(
         'id' => 'slayt_adres1',
         'label' => $txt['slayt_adres1'],
         'type' => 'text',
         ),
         array(
         'id' => 'slayt_article_upper1',
         'label' => $txt['slayt_article_upper1'],
         'type' => 'text',
         ),
        array(
         'id' => 'slayt_link1',
         'label' => $txt['slayt_link1'],
         'type' => 'text',
        ),
        array(
         'id' => 'slayt_article_lower1',
         'label' => $txt['slayt_article_lower1'],
         'type' => 'text',
        ),
        '',
        array(
         'id' => 'slayt_adres2',
         'label' => $txt['slayt_adres2'],
         'type' => 'text',
         ),
        array(
         'id' => 'slayt_article_upper2',
         'label' => $txt['slayt_article_upper2'],
         'type' => 'text',
       ),
        array(
         'id' => 'slayt_link2',
         'label' => $txt['slayt_link2'],
         'type' => 'text',
       ),
         array(
         'id' => 'slayt_article_lower2',
         'label' => $txt['slayt_article_lower2'],
         'type' => 'text',
       ),
        '',
        array(
         'id' => 'slayt_adres3',
         'label' => $txt['slayt_adres3'],
         'type' => 'text',
       ),
       array(
         'id' => 'slayt_article_upper3',
         'label' => $txt['slayt_article_upper3'],
         'type' => 'text',
       ),
      array(
         'id' => 'slayt_link3',
         'label' => $txt['slayt_link3'],
         'type' => 'text',
      ),
      array(
         'id' => 'slayt_article_lower3',
         'label' => $txt['slayt_article_lower3'],
         'type' => 'text',
       ),
        '',
       array(
         'id' => 'slayt_adres4',
         'label' => $txt['slayt_adres4'],
         'type' => 'text',
        ),
        array(
         'id' => 'slayt_article_upper4',
         'label' => $txt['slayt_article_upper4'],
         'type' => 'text',
         ),
        array(
         'id' => 'slayt_link4',
         'label' => $txt['slayt_link4'],
         'type' => 'text',
           ),
          array(
         'id' => 'slayt_article_lower4',
         'label' => $txt['slayt_article_lower4'],
         'type' => 'text',
        ),
    );
}


?>